@@ -1,8 +1,8 @@
-#!/usr/sbin/bash
+#!/bin/bash
 #
 #   ext.sh - Check that source/package extensions have valid prefixes
 #
-#   Copyright (c) 2019-2021 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2019-2025 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 [[ -n "$LIBMAKEPKG_LINT_CONFIG_EXT_SH" ]] && return
 LIBMAKEPKG_LINT_CONFIG_EXT_SH=1
 
-LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
+MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
-source "$LIBRARY/util/message.sh"
+source "$MAKEPKG_LIBRARY/util/message.sh"
 
 lint_config_functions+=('lint_ext')
 
