@@ -1,8 +1,8 @@
-#!/usr/sbin/bash
+#!/bin/bash
 #
 #   paths.sh - Check that pathname components do not contain odd characters
 #
-#   Copyright (c) 2018-2021 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2018-2025 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,10 +21,10 @@
 [[ -n "$LIBMAKEPKG_LINT_CONFIG_PATHS_SH" ]] && return
 LIBMAKEPKG_LINT_CONFIG_PATHS_SH=1
 
-LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
+MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
-source "$LIBRARY/util/message.sh"
-source "$LIBRARY/util/pkgbuild.sh"
+source "$MAKEPKG_LIBRARY/util/message.sh"
+source "$MAKEPKG_LIBRARY/util/pkgbuild.sh"
 
 lint_config_functions+=('lint_paths')
 
