@@ -1,8 +1,8 @@
-#!/usr/sbin/bash
+#!/bin/bash
 #
 #   util.sh - utility functions for makepkg
 #
-#   Copyright (c) 2015-2021 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2015-2025 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 [[ -n "$LIBMAKEPKG_UTIL_SH" ]] && return
 LIBMAKEPKG_UTIL_SH=1
 
-LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
+MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
-for lib in "$LIBRARY/util/"*.sh; do
+for lib in "$MAKEPKG_LIBRARY/util/"*.sh; do
 	source "$lib"
 done
